@@ -15,7 +15,7 @@ from PyQt5.Qt import PYQT_VERSION_STR
 from PyQt5.QtCore import QT_VERSION_STR
 import os
 import subprocess
-from pip_install import install,uninstall
+from pip_install import install,uninstall,find_moudles
 
 init(autoreset=True)
 
@@ -30,6 +30,7 @@ class moudle_installer(QtWidgets.QMainWindow,py_inst):
         self.setupUi(self)
         self.pushButton.clicked.connect(self.install)
         self.pushButton_2.clicked.connect(self.uninstall)
+        self.pushButton_3.clicked.connect(self.find_moudles)
 
 
     def install(self):
@@ -37,6 +38,8 @@ class moudle_installer(QtWidgets.QMainWindow,py_inst):
         install(self.lineEdit.text())
     def uninstall(self):
         uninstall(self.lineEdit.text())
+    def find_moudles(self):
+        find_moudles()
 
 
 
